/*
    Copyright (C) 1998 by Jorrit Tyberghein
    32-bit scanmap routines definition
    Written by Andrew Zabolotny

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef __CS_SCAN32A_H__
#define __CS_SCAN32A_H__

#define NO_scan_map_zfil
#define NO_mmx_scan_map_zfil
#define NO_scan_map_zuse
#define NO_scan_map_fixalpha50
#define NO_scan_tex_zfil
#define NO_mmx_scan_tex_zfil
#define NO_scan_fog
#define NO_scan_fog_view

#endif // __CS_SCAN32A_H__
